from kplot.lib import *

loadtheme("kg")
